cb_summarize_numeric() generates a summary table for all numeric variables
from a codebook object, optionally by group. Future releases will include options
to specify the summary statistics used. Currently, summary statistics are valid
n and %; mean and SD; median, MAD, min, max, and range; skewness, and kurtosis.
Arguments
- cb
An object of class
"li_codebook"as produced bycb_create()or a variant.- group_by
<
tidy-select> Column or columns to group by.- warn_if_none
Should a warning be issued if there are no numeric variables in
cb?
Value
If there no numeric variables in cb, NULL. Otherwise, a tibble with
columns:
optional grouping column(s) if specified in
group_byname: variable namelabel_stem: optional column containing variable label stems; included ifcbincludes alabel_stemcolumn and at least one numeric variable has a non-missing label stem.label: variable labelvalid_n,valid_pct: number and proportion of non-missing valuessummary statistic columns: by default, these include
meanand standard deviation (SD);median, median absolute deviation (MAD),min,max, andrange; skewness (skew), and kurtosis (kurt).